/* System-dependent timing definitions.  Generic version.
   Copyright (C) 1996,1997,1999,2000,2001,2002 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

/*
 * Never include this file directly; use <time.h> instead.
 */

#ifndef __need_timeval
# ifndef _BITS_TIME_H
#  define _BITS_TIME_H	1

/* ISO/IEC 9899:1990 7.12.1: <time.h>
   The macro `CLOCKS_PER_SEC' is the number per second of the value
   returned by the `clock' function. */
/* CAE XSH, Issue 4, Version 2: <time.h>
   The value of CLOCKS_PER_SEC is required to be 1 million on all
   XSI-conformant systems. */
#  define CLOCKS_PER_SEC  1000000l

#  if !defined __STRICT_ANSI__ && !defined __USE_XOPEN2K
/* Even though CLOCKS_PER_SEC has such a strange value CLK_TCK
   presents the real value for clock ticks per second for the system.  */
#   include <bits/types.h>
extern long int __sysconf (int);
#   define CLK_TCK ((__clock_t) __sysconf (2))	/* 2 is _SC_CLK_TCK */
#  endif

#  ifdef __USE_POSIX199309
/* Identifier for system-wide realtime clock.  */
#   define CLOCK_REALTIME		0
/* Monotonic system-wide clock.  */
#   define CLOCK_MONOTONIC              1
/* High-resolution timer from the CPU.  */
#   define CLOCK_PROCESS_CPUTIME_ID	2
/* Thread-specific CPU-time clock.  */
#   define CLOCK_THREAD_CPUTIME_ID	3

/* Flag to indicate time is absolute.  */
#   define TIMER_ABSTIME		1
#  endif

# endif	/* bits/time.h */
#endif

#ifdef _TPF_SOURCE                                                              //ZTPF11
/* For TPF, always define __need_timeval so the timeval structure gets defined */
#ifndef __need_timeval                                                          //ZTPF11
#define __need_timeval                                                          //ZTPF11
#endif                                                                          //ZTPF11
#endif                                                                          //ZTPF11

#ifdef __need_timeval
# undef __need_timeval
# ifndef _STRUCT_TIMEVAL
#  define _STRUCT_TIMEVAL	1
#  include <bits/types.h>

/* A time value that is accurate to the nearest
   microsecond but also has a range of years.  */
struct timeval
  {
    __time_t tv_sec;		/* Seconds.  */
    __suseconds_t tv_usec;	/* Microseconds.  */
  };
# endif	/* struct timeval */
#endif	/* need timeval */


#if defined _TPF_SOURCE && !defined __TPF_TIMESPEC                              //ZTPF11
# define __TPF_TIMESPEC 1                                                       //ZTPF11
# include <sys/cdefs.h>                                                         //ZTPF11

# ifdef __cplusplus                                                             //ZTPF11
extern "C"                                                                      //ZTPF11
{                                                                               //ZTPF11
# endif                                                                         //ZTPF11

struct timespec {                                                               //ZTPF11
    __time_t    tv_sec;         /* seconds */                                   //ZTPF11
    long int    tv_nsec;        /* and nanoseconds  */                          //ZTPF11
#define ts_sec  tv_sec
#define ts_nsec tv_nsec
 };

# ifndef _POSIX_SOURCE                                                          //ZTPF11

__BEGIN_DECLS                                                                   //ZTPF11
int utimes __P((const char *, const struct timeval *));                         //ZTPF11
__END_DECLS                                                                     //ZTPF11

# endif /* !POSIX */                                                            //ZTPF11

/*
 * Modified BSD style select() related macros and structure
*/

# ifndef __FD_SET_MACROS                                                        //ZTPF11
 # define __FD_SET_MACROS                                                       //ZTPF11

/*
 * Here, FD_SETSIZE is the maximum number of sockets
 * supported, instead of the largest descriptor.  Use a
 * test macro so that the application can define its own.
*/

  # ifndef FD_SETSIZE                                                           //ZTPF11
    # define FD_SETSIZE  256                                                    //ZTPF11
  # endif /*FD_SETSIZE*/                                                        //ZTPF11

  typedef long fd_mask;                                                         //ZTPF11
  # define NFDBITS (sizeof(fd_mask) * NBBY)                                     //ZTPF11
                           /* bits per mask */

  typedef struct fd_set {                                                       //ZTPF11
    int fds[FD_SETSIZE];                                                        //ZTPF11
  } fd_set;                                                                     //ZTPF11

  extern int tpf_select_bsd(int, fd_set*, fd_set*,                              //ZTPF11
                          fd_set *, struct timeval *);                          //ZTPF11
  extern void __fd_set(int, fd_set *);                                          //ZTPF11
  extern void __fd_clr(int, fd_set *);                                          //ZTPF11
  extern int __fd_isset(int, fd_set *);                                         //ZTPF11

  # define FD_SET(n, p) __fd_set((n), (p))                                      //ZTPF11
  # define FD_CLR(n, p) __fd_clr((n), (p))                                      //ZTPF11
  # define FD_ISSET(n, p) __fd_isset((n), (p))                                  //ZTPF11
  # define FD_COPY(f, t) bcopy(f, t, sizeof(*(f)))                              //ZTPF11
  # define FD_ZERO(p) memset(p, 255, sizeof(*(p)))                              //ZTPF11
# endif /*__FD_SET_MACROS*/                                                     //ZTPF11 

# ifndef howmany                                                                //ZTPF11
 # define howmany(x, y) (((x)+((y)-1))/(y))                                     //ZTPF11
# endif                                                                         //ZTPF11

# ifdef __cplusplus                                                             //ZTPF11
}                                                                               //ZTPF11
# endif

#endif  /* _TPF_SOURCE */                                                       //ZTPF11
